@@ -153,14 +153,14 @@ simDynoccSpatial <- function(side = 50, nyears = 10, nsurveys = 3,
   # Create values of 1 spatially autocorrelated covariate XAC
   # Generate correlated random variables in a square
   
-  if(requireNamespace("RandomFields", quietly=TRUE)) {
-    RandomFields::RFoptions(seed=seed.XAC)     # Default NA; 88 gives cool pattern
-    XAC <- matrix(RandomFields::RFsimulate(RandomFields::RMexp(var = 1, scale = theta.XAC),
-        x=xcoord, y=ycoord, grid=TRUE)@data$variable1,
-        ncol = side, byrow = TRUE)  # variance 1
-    if(!is.na(seed.XAC))
-      RandomFields::RFoptions(seed=NA)
-  } else {
+  #if(requireNamespace("RandomFields", quietly=TRUE)) {
+  #  RandomFields::RFoptions(seed=seed.XAC)     # Default NA; 88 gives cool pattern
+  #  XAC <- matrix(RandomFields::RFsimulate(RandomFields::RMexp(var = 1, scale = theta.XAC),
+  #      x=xcoord, y=ycoord, grid=TRUE)@data$variable1,
+  #      ncol = side, byrow = TRUE)  # variance 1
+  #  if(!is.na(seed.XAC))
+  #    RandomFields::RFoptions(seed=NA)
+  #} else {
     message("Using package 'fields' instead of 'RandomFields'; see help(simDynoccSpatial).")
     if(!is.na(seed.XAC))
       set.seed(seed.XAC)
@@ -169,7 +169,7 @@ simDynoccSpatial <- function(side = 50, nyears = 10, nsurveys = 3,
     if(inherits(tmp, "try-error"))
       stop("Simulation of random field failed.\nTry with smaller values for 'side' or 'theta.XAC'.")
     XAC <- matrix(tmp, ncol = side, byrow = TRUE)
-  }
+  #}
  
   set.seed(seed=seed)  # Default NULL; do this AFTER RFsimulate
 
